/**
 ******************************************************************************
 * @addtogroup UAVObjects OpenPilot UAVObjects
 * @{ 
 * @addtogroup GuidanceSettings GuidanceSettings 
 * @brief PID settings used by the Guidance module to combine the @ref PositionActual and @ref PositionDesired to compute @ref AttitudeDesired
 *
 * Autogenerated files and functions for GuidanceSettings Object
 
 * @{ 
 *
 * @file       guidancesettings.h
 * @author     The OpenPilot Team, http://www.openpilot.org Copyright (C) 2010.
 * @brief      Implementation of the GuidanceSettings object. This file has been 
 *             automatically generated by the UAVObjectGenerator.
 * 
 * @note       Object definition file: guidancesettings.xml. 
 *             This is an automatically generated file.
 *             DO NOT modify manually.
 *
 * @see        The GNU Public License (GPL) Version 3
 *
 *****************************************************************************/
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIDANCESETTINGS_H
#define GUIDANCESETTINGS_H

// Object constants
#define GUIDANCESETTINGS_OBJID 2093064904U
#define GUIDANCESETTINGS_NAME "GuidanceSettings"
#define GUIDANCESETTINGS_METANAME "GuidanceSettingsMeta"
#define GUIDANCESETTINGS_ISSINGLEINST 1
#define GUIDANCESETTINGS_ISSETTINGS 1
#define GUIDANCESETTINGS_NUMBYTES sizeof(GuidanceSettingsData)

// Object access macros
/**
 * @function GuidanceSettingsGet(dataOut)
 * @brief Populate a GuidanceSettingsData object
 * @param[out] dataOut 
 */
#define GuidanceSettingsGet(dataOut) UAVObjGetData(GuidanceSettingsHandle(), dataOut)
#define GuidanceSettingsSet(dataIn) UAVObjSetData(GuidanceSettingsHandle(), dataIn)
#define GuidanceSettingsInstGet(instId, dataOut) UAVObjGetInstanceData(GuidanceSettingsHandle(), instId, dataOut)
#define GuidanceSettingsInstSet(instId, dataIn) UAVObjSetInstanceData(GuidanceSettingsHandle(), instId, dataIn)
#define GuidanceSettingsConnectQueue(queue) UAVObjConnectQueue(GuidanceSettingsHandle(), queue, EV_MASK_ALL_UPDATES)
#define GuidanceSettingsConnectCallback(cb) UAVObjConnectCallback(GuidanceSettingsHandle(), cb, EV_MASK_ALL_UPDATES)
#define GuidanceSettingsCreateInstance() UAVObjCreateInstance(GuidanceSettingsHandle())
#define GuidanceSettingsRequestUpdate() UAVObjRequestUpdate(GuidanceSettingsHandle())
#define GuidanceSettingsRequestInstUpdate(instId) UAVObjRequestInstanceUpdate(GuidanceSettingsHandle(), instId)
#define GuidanceSettingsUpdated() UAVObjUpdated(GuidanceSettingsHandle())
#define GuidanceSettingsInstUpdated(instId) UAVObjUpdated(GuidanceSettingsHandle(), instId)
#define GuidanceSettingsGetMetadata(dataOut) UAVObjGetMetadata(GuidanceSettingsHandle(), dataOut)
#define GuidanceSettingsSetMetadata(dataIn) UAVObjSetMetadata(GuidanceSettingsHandle(), dataIn)
#define GuidanceSettingsReadOnly(dataIn) UAVObjReadOnly(GuidanceSettingsHandle())

// Object data
typedef struct {
    uint16_t UpdatePeriod;
    float RollMax;
    float PitchMax;
    float PitchMin;
    float PitchRollEpsilon;
    float ThrottleMax;
    float ThrottleMin;
    float SpeedMax;
    float SpeedMin;
    float SpeedKp;
    float SpeedKi;
    float SpeedKd;
    float EnergyKp;
    float EnergyKi;
    float EnergyKd;
    float LateralKp;
    float LateralKi;
    float LateralKd;
    float CourseKp;
    float CourseKi;
    float CourseKd;

} __attribute__((packed)) GuidanceSettingsData;

// Field information
// Field UpdatePeriod information
// Field RollMax information
// Field PitchMax information
// Field PitchMin information
// Field PitchRollEpsilon information
// Field ThrottleMax information
// Field ThrottleMin information
// Field SpeedMax information
// Field SpeedMin information
// Field SpeedKp information
// Field SpeedKi information
// Field SpeedKd information
// Field EnergyKp information
// Field EnergyKi information
// Field EnergyKd information
// Field LateralKp information
// Field LateralKi information
// Field LateralKd information
// Field CourseKp information
// Field CourseKi information
// Field CourseKd information


// Generic interface functions
int32_t GuidanceSettingsInitialize();
UAVObjHandle GuidanceSettingsHandle();

#endif // GUIDANCESETTINGS_H

/**
 * @}
 * @}
 */
